@@ -20,12 +20,23 @@
 #include <QApplication>
 #include <QTranslator>
 #include <QSettings>
-#include "scriptwindow.h"
-#include "finddialog.h"
+#include <QTextCodec>
+#include <QTextCodec>
+#include "udav_wnd.h"
+#include "hint_dlg.h"
 #include <mgl/mgl_parse.h>
 #include <mgl/mgl_eval.h>
 //-----------------------------------------------------------------------------
+#ifndef UDAV_DIR
+#ifdef WIN32
+#define UDAV_DIR ""
+#else
+#define UDAV_DIR "/usr/local/share/udav/"
+#endif
+#endif
+//-----------------------------------------------------------------------------
 extern mglParse parser;
+extern QString pathFont;
 int mgl_cmd_cmp(const void *a, const void *b);
 HintDialog *hintDialog=NULL;
 QString pathHelp=MGL_DOC_DIR;
@@ -37,26 +48,34 @@ int main(int argc, char **argv)
 {
 	QApplication a(argc, argv);
 	QTranslator translator;
+//QTextCodec::setCodecForCStrings(QTextCodec::codecForName("UTF-8"));
 
 	QString lang="";
-	QSettings settings("abalakin","UDAV");
+	QSettings settings("udav","UDAV");
 	settings.setPath(QSettings::IniFormat, QSettings::UserScope, "UDAV");
 	settings.beginGroup("/UDAV");
 	pathHelp = settings.value("/helpPath", MGL_DOC_DIR).toString();
+	pathFont = settings.value("/userFont", "").toString();
 	lang = settings.value("/udavLang", "").toString();
 	settings.endGroup();
+	if(pathHelp.isEmpty())	pathHelp=MGL_DOC_DIR;
 
 	if(!lang.isEmpty())
 	{
-		translator.load("udav_"+lang, pathHelp);
+		if(!translator.load("udav_"+lang, UDAV_DIR))
+			translator.load("udav_"+lang, pathHelp);
 		a.installTranslator(&translator);
 	}
 
 	udavLoadDefCommands();
 	hintDialog = new HintDialog();
-	ScriptWindow *mw = new ScriptWindow();
-	if(argc>1)	mw->load(QString(argv[1]), true);
-	mw->show();
+	MainWindow *mw = new MainWindow();
+	if(argc>1)
+	{
+		QTextCodec *codec = QTextCodec::codecForLocale();
+		mw->load(codec->toUnicode(argv[1]), true);
+	}
+	mw->show();//	mw->edit->setCursorPosition(0);
 	a.connect(&a, SIGNAL(lastWindowClosed()), &a, SLOT(quit()));
 	if(showHint)	hintDialog->exec();
 	return a.exec();
