@@ -28,22 +28,24 @@
 #include <QCursor>
 #include <QImage>
 #include <QFileInfo>
+#include <QProcess>
+#include <QStringList>
 #include <stdio.h>
 #include <mgl/mgl_parse.h>
 #include <mgl/mgl_idtf.h>
 #include <mgl/mgl_eps.h>
 #include "qmglcanvas.h"
 extern mglParse parser;
+extern bool mglAutoPure;
 //-----------------------------------------------------------------------------
 QMGLCanvas::QMGLCanvas(QWidget *parent, Qt::WindowFlags f) : QWidget(parent, f)
 {
 	autoResize = false;
 	textMGL = warnMGL = 0;	appName = tr("UDAV");
-	graph = new mglGraphZB;
-	popup = 0;		grBuf = 0;
-	phi = tet = per = 0;
+	popup = 0;	grBuf = 0;	phi = tet = per = 0;
 	x1 = y1 = 0;	x2 = y2 = 1;
 	alpha = light = zoom = rotate = grid = false;
+	graph = new mglGraphZB;
 	resize(graph->GetWidth(), graph->GetHeight());
 	convertFromGraph(pic, graph, &grBuf);
 	thr = new MGLThread();	thr->cnv = this;
@@ -75,7 +77,7 @@ void QMGLCanvas::paintEvent(QPaintEvent *)
 //-----------------------------------------------------------------------------
 void QMGLCanvas::resizeEvent(QResizeEvent *ev)
 {
-	if(autoResize)
+	if(autoResize && ev->size().width()>0 && ev->size().height()>0)
 	{	graph->SetSize(ev->size().width(), ev->size().height());	execute();	repaint();	}
 	else	resize(graph->GetWidth(), graph->GetHeight());
 }
@@ -86,7 +88,9 @@ void QMGLCanvas::setPer(int p)
 	{	per = 100*p;	emit perChanged(p);	execute();	}
 }
 //-----------------------------------------------------------------------------
-void QMGLCanvas::imgSize(int w, int h)	{	graph->SetSize(w,h);	execute();	}
+void QMGLCanvas::imgSize(int w, int h)
+{	if(w<=0 || h<=0)	return;
+	graph->SetSize(w,h);	execute();	}
 //-----------------------------------------------------------------------------
 void QMGLCanvas::setPhi(int p)
 {	if(phi!=p)	{	phi = p;	emit phiChanged(p);	execute();	}	}
@@ -159,25 +163,26 @@ void QMGLCanvas::zoomOut()
 	execute();
 }
 //-----------------------------------------------------------------------------
-void QMGLCanvas::execute(mglGraphAB *gr)
+void QMGLCanvas::execute(mglGraphAB *gr, int line)
 {
 	if(!textMGL && autoResize)	{	run(defText, false, gr);	return;	}
 	else if(!textMGL)	return;
-	run(textMGL->toPlainText(), true, gr);
-	emit refreshData();
+	run(textMGL->toPlainText(), true, gr, line);
 	if(pic.size()!=size())	setSize(pic.width(), pic.height());
+	emit refreshData();
 }
 //-----------------------------------------------------------------------------
-QString QMGLCanvas::run(const QString &text, bool showm, mglGraphAB *gr)
+QString QMGLCanvas::run(const QString &text, bool showm, mglGraphAB *gr, int line)
 {
 	defText = text;
 	if(gr==0)	gr=graph;
+	if(gr==0)	return QString(tr("Not initialized!"));
 	gr->DefaultPlotParam();
 	gr->Alpha(alpha);	gr->Light(light);
 	gr->View(tet,phi);	gr->Org = mglPoint(NAN,NAN,NAN);
 	gr->Perspective(per);
 	gr->Zoom(x1,y1,x2,y2);
-	gr->DrawFace = !rotate;
+	gr->DrawFace = !(rotate && mglAutoPure);
 	if(text.count("rotate ")==0 && text.count("rotate\t")==0)	gr->Rotate(0,0);
 	parser.Stop = false;
 	parser.AllowSetSize = true;
@@ -185,20 +190,18 @@ QString QMGLCanvas::run(const QString &text, bool showm, mglGraphAB *gr)
 
 	if(warnMGL && !warnMGL->toPlainText().isEmpty())	warnMGL->clear();
 	// At least now I don't want use setup script ! So I skip this code
-	if(!isHidden())
-		QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
-	thr->gr = gr;	thr->text = text;
-	thr->start();
+	if(!isHidden())	QApplication::setOverrideCursor(QCursor(Qt::WaitCursor));
+	if(!thr->isRunning())
+	{
+		thr->gr = gr;	thr->text = text;
+		thr->line = line;	thr->start();
+	}
 	if(rotate)	thr->wait();
 	else	while(thr->isRunning())	qApp->processEvents();
 	if(warnMGL)	warnMGL->setText(thr->warn);
-	if(!isHidden())
-		QApplication::restoreOverrideCursor();
+	if(!isHidden())	QApplication::restoreOverrideCursor();
 	if(gr==graph)
-	{
-		convertFromGraph(pic, graph, &grBuf);
-		repaint();
-	}
+	{	convertFromGraph(pic, graph, &grBuf);	repaint();	}
 	return thr->mes;
 }
 //-----------------------------------------------------------------------------
@@ -209,14 +212,42 @@ void MGLThread::run()
 	gr->Message = buf;	warn = "";
 	wchar_t *str = new wchar_t[text.length()+2];
 	QString cur;
+	bool high;
 	// Start parsing the text (just slightly modified copy from mgl_parse.cpp)
+	parser.ScanFunc(0);		for(i=0;i<n;i++)
+	{
+		cur = text.section('\n',i,i);	high = false;
+		r = cur.toWCharArray(str);	str[r] = 0;
+		parser.ScanFunc(str);
+	}
 	for(i=0;i<n && !parser.Stop;i++)
 	{
-		cur = text.section('\n',i,i);
+		cur = text.section('\n',i,i);	high = false;
+
+		if(i==line)
+		{
+			wchar_t *s = new wchar_t[cur.length()+1];
+			register int j;
+			for(j=0;j<cur.length() && !cur[j].isSpace() && cur[j]!=':';j++)
+				s[j] = text[j].toLatin1();
+			s[j]=0;
+			mglCommand *rts = parser.FindCommand(s);
+			if(rts && (rts->type==0 || rts->type==1))	high = true;
+			delete []s;
+		}
+
 		r = cur.toWCharArray(str);	str[r] = 0;
 		gr->Message[0] = 0;			gr->ObjId = i+1;
 		setlocale(LC_ALL, "C");
 		r = parser.Parse(gr,str,i+1);
+		if(!r && high)
+		{
+			double bw = gr->BaseLineWidth;
+			bool df = gr->DrawFace;
+			gr->BaseLineWidth = bw ? bw*2 : 2;	gr->DrawFace = false;
+			parser.Parse(gr,str,i+1);
+			gr->BaseLineWidth = bw;		gr->DrawFace = df;
+		}
 		setlocale(LC_ALL, "");
 		if(r<0)	{	i = -r-2;	continue;	}
 		if(r>0)
@@ -231,7 +262,7 @@ void MGLThread::run()
 		}
 		if(gr->Message && gr->Message[0]!=0)
 		{
-			mes = tr("In line ")+QString::number(i)+tr(" :\t");
+			mes = tr("In line ")+QString::number(i)+" :\t";
 			mes = mes + cur + "\n" + QString(gr->Message) + "\n";
 			warn += mes + "\n";
 		}
@@ -251,7 +282,7 @@ void QMGLCanvas::mousePressEvent(QMouseEvent *ev)
 	if(!zoom && !rotate && ev->button()&Qt::LeftButton)
 	{
 		mglPoint p = graph->CalcXYZ(ev->x(), ev->y());
-		clickPos.sprintf("x=%g, y=%g, z=%g  --  Xabs=%g, Yabs=%g",
+		clickPos.sprintf("x=%g, y=%g, z=%g  --  Xabs=%.3g, Yabs=%.3g",
 					p.x,p.y,p.z,double(ev->x())/graph->GetWidth(),
 					1-double(ev->y())/graph->GetHeight());
 		emit posChanged(clickPos);
@@ -374,7 +405,7 @@ void QMGLCanvas::exportBPS(QString fname)
 	else
 	{
 		setlocale(LC_ALL, "C");
-		graph->WriteEPS(setExtension(fname,"eps").toAscii(), appName.toAscii());
+		graph->WriteEPS(setExtension(fname,"eps.gz").toAscii(), appName.toAscii());
 		setlocale(LC_ALL, "");
 	}
 }
@@ -390,6 +421,8 @@ void QMGLCanvas::exportEPS(QString fname)
 		execute(ps);
 		setlocale(LC_ALL, "C");
 		ps->WriteEPS(setExtension(fname,"eps").toAscii(), appName.toAscii());
+		QStringList arg;	arg<<setExtension(fname,"eps");
+		QProcess::execute("epstopdf", arg);
 		setlocale(LC_ALL, "");
 		delete ps;
 	}
@@ -405,7 +438,7 @@ void QMGLCanvas::exportSVG(QString fname)
 		ps->SetFont(graph->GetFont());
 		execute(ps);
 		setlocale(LC_ALL, "C");
-		ps->WriteSVG(setExtension(fname,"svg").toAscii(), appName.toAscii());
+		ps->WriteSVG(setExtension(fname,"svgz").toAscii(), appName.toAscii());
 		setlocale(LC_ALL, "");
 		delete ps;
 	}
@@ -504,5 +537,6 @@ void QMGLCanvas::setMGLFont(QString path)
 }
 //-----------------------------------------------------------------------------
 void QMGLCanvas::setSize(int w, int h)
-{	graph->SetSize(w,h);	resize(w, h);	execute();	}
+{	if(w<=0 || h<=0)	return;
+	graph->SetSize(w,h);	resize(w, h);	execute();	}
 //-----------------------------------------------------------------------------
