@@ -37,6 +37,7 @@ protected:
 	mglGraphAB *gr;
 	QString mes;	///< gr->Message after execution
 	QString text;	///< text for parsing
+	int line;		///< line to highlite
 	QString warn;
 	void run();
 };
@@ -59,12 +60,13 @@ public:
 	double getRatio()	{	return double(graph->GetWidth())/graph->GetHeight();	};
 	void setPopup(QMenu *p)	{	popup = p;	};
 	void setSize(int w, int h);
-	QString run(const QString &text, bool showm=true, mglGraphAB *gr=0);	///< Execute script from string
-//	void showMess(const QString &mes);
+	/// Execute script from string
+	QString run(const QString &text, bool showm=true, mglGraphAB *gr=0, int line=-1);
+	const QPixmap &getPic()	{	return pic;	};	///< Pixmap for drawing
 signals:
 	void refreshData();
 public slots:
-	void execute(mglGraphAB *gr=0);	///< Execute script (and update picture)
+	void execute(mglGraphAB *gr=0, int line=-1);	///< Execute script (and update picture)
 	void copy();			///< copy graphics to clipboard
 	void copyClickCoor();	///< copy click coordinates to clipboard
 	void stop();			///< Stop execution
